@@ -1,7 +1,7 @@
 """Collection of public constants for XRPL."""
+import re
 from decimal import Context
 from enum import Enum
-from re import compile
 from typing import Pattern
 
 from typing_extensions import Final
@@ -20,13 +20,17 @@ class XRPLException(Exception):
     pass
 
 
-ISO_CURRENCY_REGEX: Final[Pattern[str]] = compile("^[A-Z0-9]{3}$")
+ISO_CURRENCY_REGEX: Final[Pattern[str]] = re.compile("[A-Z0-9]{3}")
 """
+Matches ISO currencies like "USD" or "EUR" in the format allowed by XRPL.
+
 :meta private:
 """
 
-HEX_CURRENCY_REGEX: Final[Pattern[str]] = compile("^[A-F0-9]{40}$")
+HEX_CURRENCY_REGEX: Final[Pattern[str]] = re.compile("[A-F0-9]{40}")
 """
+Matches hex-encoded currencies in the format allowed by XRPL.
+
 :meta private:
 """
 
