@@ -12,6 +12,14 @@ from xrpl.models.transactions.deposit_preauth import DepositPreauth
 from xrpl.models.transactions.escrow_cancel import EscrowCancel
 from xrpl.models.transactions.escrow_create import EscrowCreate
 from xrpl.models.transactions.escrow_finish import EscrowFinish
+from xrpl.models.transactions.nftoken_accept_offer import NFTokenAcceptOffer
+from xrpl.models.transactions.nftoken_burn import NFTokenBurn
+from xrpl.models.transactions.nftoken_cancel_offer import NFTokenCancelOffer
+from xrpl.models.transactions.nftoken_create_offer import (
+    NFTokenCreateOffer,
+    NFTokenCreateOfferFlag,
+)
+from xrpl.models.transactions.nftoken_mint import NFTokenMint, NFTokenMintFlag
 from xrpl.models.transactions.offer_cancel import OfferCancel
 from xrpl.models.transactions.offer_create import OfferCreate, OfferCreateFlag
 from xrpl.models.transactions.payment import Payment, PaymentFlag
@@ -23,7 +31,8 @@ from xrpl.models.transactions.payment_channel_create import PaymentChannelCreate
 from xrpl.models.transactions.payment_channel_fund import PaymentChannelFund
 from xrpl.models.transactions.set_regular_key import SetRegularKey
 from xrpl.models.transactions.signer_list_set import SignerEntry, SignerListSet
-from xrpl.models.transactions.transaction import Memo, Signer
+from xrpl.models.transactions.ticket_create import TicketCreate
+from xrpl.models.transactions.transaction import Memo, Signer, Transaction
 from xrpl.models.transactions.trust_set import TrustSet, TrustSetFlag
 
 __all__ = [
@@ -38,6 +47,13 @@ __all__ = [
     "EscrowCreate",
     "EscrowFinish",
     "Memo",
+    "NFTokenAcceptOffer",
+    "NFTokenBurn",
+    "NFTokenCancelOffer",
+    "NFTokenCreateOffer",
+    "NFTokenCreateOfferFlag",
+    "NFTokenMint",
+    "NFTokenMintFlag",
     "OfferCancel",
     "OfferCreate",
     "OfferCreateFlag",
@@ -51,6 +67,8 @@ __all__ = [
     "Signer",
     "SignerEntry",
     "SignerListSet",
+    "TicketCreate",
+    "Transaction",
     "TrustSet",
     "TrustSetFlag",
 ]
