@@ -1,11 +1,12 @@
 """The base model for all transactions and their nested object types."""
 from __future__ import annotations
 
-import re
 from dataclasses import dataclass
 from hashlib import sha512
 from typing import Any, Dict, List, Optional, Type, Union, cast
 
+from typing_extensions import Final
+
 from xrpl.core.binarycodec import encode
 from xrpl.models.amounts import IssuedCurrencyAmount
 from xrpl.models.base_model import BaseModel
@@ -13,12 +14,22 @@ from xrpl.models.exceptions import XRPLModelException
 from xrpl.models.requests import PathStep
 from xrpl.models.required import REQUIRED
 from xrpl.models.transactions.types import PseudoTransactionType, TransactionType
+from xrpl.models.types import XRPL_VALUE_TYPE
 from xrpl.models.utils import require_kwargs_on_init
 
-_TRANSACTION_HASH_PREFIX = 0x54584E00
+_TRANSACTION_HASH_PREFIX: Final[int] = 0x54584E00
+# This is used to make exceptions when converting dictionary keys to xrpl JSON
+# keys. We snake case keys, but some keys are abbreviations.
+_ABBREVIATIONS: Final[List[str]] = [
+    "unl",
+    "id",
+    "uri",
+]
 
 
-def transaction_json_to_binary_codec_form(dictionary: Dict[str, Any]) -> Dict[str, Any]:
+def transaction_json_to_binary_codec_form(
+    dictionary: Dict[str, XRPL_VALUE_TYPE]
+) -> Dict[str, XRPL_VALUE_TYPE]:
     """
     Returns a new dictionary in which the keys have been formatted as CamelCase and
     standardized to be serialized by the binary codec.
@@ -37,11 +48,22 @@ def transaction_json_to_binary_codec_form(dictionary: Dict[str, Any]) -> Dict[st
 
 
 def _key_to_tx_json(key: str) -> str:
-    snaked = "".join([word.capitalize() for word in key.split("_")])
-    return re.sub(r"Unl", r"UNL", re.sub(r"Id", r"ID", snaked))
+    """
+    Transforms snake_case to PascalCase. For example:
+        1. 'transaction_type' becomes 'TransactionType'
+        2. 'URI' becomes 'uri'
+
+    Known abbreviations (example 2 above) need to be enumerated in _ABBREVIATIONS.
+    """
+    return "".join(
+        [
+            word.upper() if word in _ABBREVIATIONS else word.capitalize()
+            for word in key.split("_")
+        ]
+    )
 
 
-def _value_to_tx_json(value: Any) -> Any:
+def _value_to_tx_json(value: XRPL_VALUE_TYPE) -> XRPL_VALUE_TYPE:
     # IssuedCurrencyAmount and PathStep are special cases and should not be snake cased
     # and only contain primitive members
     if IssuedCurrencyAmount.is_dict_of_model(value) or PathStep.is_dict_of_model(value):
@@ -160,7 +182,7 @@ class Signer(BaseModel):
     """
 
     @classmethod
-    def is_dict_of_model(cls: Type[Signer], dictionary: Dict[str, Any]) -> bool:
+    def is_dict_of_model(cls: Type[Signer], dictionary: Any) -> bool:
         """
         Returns True if the input dictionary was derived by the `to_dict`
         method of an instance of this class. In other words, True if this is
