@@ -15,6 +15,11 @@ class TransactionType(str, Enum):
     ESCROW_CANCEL = "EscrowCancel"
     ESCROW_CREATE = "EscrowCreate"
     ESCROW_FINISH = "EscrowFinish"
+    NFTOKEN_ACCEPT_OFFER = "NFTokenAcceptOffer"
+    NFTOKEN_BURN = "NFTokenBurn"
+    NFTOKEN_CANCEL_OFFER = "NFTokenCancelOffer"
+    NFTOKEN_CREATE_OFFER = "NFTokenCreateOffer"
+    NFTOKEN_MINT = "NFTokenMint"
     OFFER_CANCEL = "OfferCancel"
     OFFER_CREATE = "OfferCreate"
     PAYMENT = "Payment"
@@ -23,4 +28,5 @@ class TransactionType(str, Enum):
     PAYMENT_CHANNEL_FUND = "PaymentChannelFund"
     SET_REGULAR_KEY = "SetRegularKey"
     SIGNER_LIST_SET = "SignerListSet"
+    TICKET_CREATE = "TicketCreate"
     TRUST_SET = "TrustSet"
