@@ -120,3 +120,24 @@ def safe_sign_and_autofill_transaction(
             check_fee,
         )
     )
+
+
+def autofill(transaction: Transaction, client: SyncClient) -> Transaction:
+    """
+    Autofills fields in a transaction. This will set `sequence`, `fee`, and
+    `last_ledger_sequence` according to the current state of the server this Client is
+    connected to. It also converts all X-Addresses to classic addresses.
+
+    Args:
+        transaction: the transaction to be signed.
+        client: a network client.
+
+    Returns:
+        The autofilled transaction.
+    """
+    return asyncio.run(
+        main.autofill(
+            transaction,
+            client,
+        )
+    )
