@@ -1,5 +1,6 @@
 """Convenience utilities for the XRP Ledger"""
 
+from xrpl.utils.str_conversions import hex_to_str, str_to_hex
 from xrpl.utils.time_conversions import (
     XRPLTimeRangeException,
     datetime_to_ripple_time,
@@ -10,6 +11,8 @@ from xrpl.utils.time_conversions import (
 from xrpl.utils.xrp_conversions import XRPRangeException, drops_to_xrp, xrp_to_drops
 
 __all__ = [
+    "str_to_hex",
+    "hex_to_str",
     "xrp_to_drops",
     "drops_to_xrp",
     "ripple_time_to_datetime",
